<?php
declare(strict_types=1);

namespace App\Validator;

use App\Service\CurrencyListerInterface;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;
use Symfony\Component\Validator\Exception\UnexpectedTypeException;
use Symfony\Component\Validator\Exception\UnexpectedValueException;

class CurrencyValidator extends ConstraintValidator {
    public function __construct(private readonly CurrencyListerInterface $currencyLister) {}
    public function validate(mixed $value, Constraint $constraint): void
    {
        if (!$constraint instanceof Currency) {
            throw new UnexpectedTypeException($constraint, Currency::class);
        }

        if (null === $value || '' === $value) {
            return ;
        }

        if (is_string($value) === false) {
            throw new UnexpectedValueException($value, "string");
        }

        $availCurrencies = iterator_to_array($this->currencyLister->getCurrencies());

        if (in_array($value, $availCurrencies, true)) {
            return ;
        }

        $this->context->buildViolation($constraint->message)
            ->setParameter('{{ string }}', $value)
            ->addViolation();
    }
}
